@@ -5,11 +5,9 @@ import json
 import re
 import six
 
-from boto.exception import JSONResponseError
-from boto.kms.exceptions import AlreadyExistsException, NotFoundException
-
 from moto.core.responses import BaseResponse
 from .models import kms_backends
+from .exceptions import NotFoundException, ValidationException, AlreadyExistsException, NotAuthorizedException
 
 reserved_aliases = [
     'alias/aws/ebs',
@@ -88,36 +86,28 @@ class KmsResponse(BaseResponse):
     def create_alias(self):
         alias_name = self.parameters['AliasName']
         target_key_id = self.parameters['TargetKeyId']
-        region = self.region
 
         if not alias_name.startswith('alias/'):
-            raise JSONResponseError(400, 'Bad Request',
-                                    body={'message': 'Invalid identifier', '__type': 'ValidationException'})
+            raise ValidationException('Invalid identifier')
 
         if alias_name in reserved_aliases:
-            raise JSONResponseError(400, 'Bad Request', body={
-                                    '__type': 'NotAuthorizedException'})
+            raise NotAuthorizedException()
 
         if ':' in alias_name:
-            raise JSONResponseError(400, 'Bad Request', body={
-                'message': '{alias_name} contains invalid characters for an alias'.format(**locals()),
-                '__type': 'ValidationException'})
+            raise ValidationException('{alias_name} contains invalid characters for an alias'.format(alias_name=alias_name))
 
         if not re.match(r'^[a-zA-Z0-9:/_-]+$', alias_name):
-            raise JSONResponseError(400, 'Bad Request', body={
-                'message': "1 validation error detected: Value '{alias_name}' at 'aliasName' failed to satisfy constraint: Member must satisfy regular expression pattern: ^[a-zA-Z0-9:/_-]+$"
-                                    .format(**locals()),
-                                    '__type': 'ValidationException'})
+            raise ValidationException("1 validation error detected: Value '{alias_name}' at 'aliasName' "
+                                  "failed to satisfy constraint: Member must satisfy regular "
+                                  "expression pattern: ^[a-zA-Z0-9:/_-]+$"
+                                      .format(alias_name=alias_name))
 
         if self.kms_backend.alias_exists(target_key_id):
-            raise JSONResponseError(400, 'Bad Request', body={
-                'message': 'Aliases must refer to keys. Not aliases',
-                '__type': 'ValidationException'})
+            raise ValidationException('Aliases must refer to keys. Not aliases')
 
         if self.kms_backend.alias_exists(alias_name):
-            raise AlreadyExistsException(400, 'Bad Request', body={
-                'message': 'An alias with the name arn:aws:kms:{region}:012345678912:{alias_name} already exists'
-                                         .format(**locals()), '__type': 'AlreadyExistsException'})
+            raise AlreadyExistsException('An alias with the name arn:aws:kms:{region}:012345678912:{alias_name} '
+                                         'already exists'.format(region=self.region, alias_name=alias_name))
 
         self.kms_backend.add_alias(target_key_id, alias_name)
 
@@ -125,16 +115,13 @@ class KmsResponse(BaseResponse):
 
     def delete_alias(self):
         alias_name = self.parameters['AliasName']
-        region = self.region
 
         if not alias_name.startswith('alias/'):
-            raise JSONResponseError(400, 'Bad Request',
-                                    body={'message': 'Invalid identifier', '__type': 'ValidationException'})
+            raise ValidationException('Invalid identifier')
 
         if not self.kms_backend.alias_exists(alias_name):
-            raise NotFoundException(400, 'Bad Request', body={
-                'message': 'Alias arn:aws:kms:{region}:012345678912:{alias_name} is not found.'.format(**locals()),
-                '__type': 'NotFoundException'})
+            raise NotFoundException('Alias arn:aws:kms:{region}:012345678912:'
+                                    '{alias_name} is not found.'.format(region=self.region, alias_name=alias_name))
 
         self.kms_backend.delete_alias(alias_name)
 
@@ -172,9 +159,8 @@ class KmsResponse(BaseResponse):
         try:
             self.kms_backend.enable_key_rotation(key_id)
         except KeyError:
-            raise JSONResponseError(404, 'Not Found', body={
-                'message': "Key 'arn:aws:kms:{region}:012345678912:key/{key_id}' does not exist".format(region=self.region, key_id=key_id),
-                '__type': 'NotFoundException'})
+            raise NotFoundException("Key 'arn:aws:kms:{region}:012345678912:key/"
+                                    "{key_id}' does not exist".format(region=self.region, key_id=key_id))
 
         return json.dumps(None)
 
@@ -184,9 +170,8 @@ class KmsResponse(BaseResponse):
         try:
             self.kms_backend.disable_key_rotation(key_id)
         except KeyError:
-            raise JSONResponseError(404, 'Not Found', body={
-                'message': "Key 'arn:aws:kms:{region}:012345678912:key/{key_id}' does not exist".format(region=self.region, key_id=key_id),
-                '__type': 'NotFoundException'})
+            raise NotFoundException("Key 'arn:aws:kms:{region}:012345678912:key/"
+                                    "{key_id}' does not exist".format(region=self.region, key_id=key_id))
         return json.dumps(None)
 
     def get_key_rotation_status(self):
@@ -195,9 +180,8 @@ class KmsResponse(BaseResponse):
         try:
             rotation_enabled = self.kms_backend.get_key_rotation_status(key_id)
         except KeyError:
-            raise JSONResponseError(404, 'Not Found', body={
-                'message': "Key 'arn:aws:kms:{region}:012345678912:key/{key_id}' does not exist".format(region=self.region, key_id=key_id),
-                '__type': 'NotFoundException'})
+            raise NotFoundException("Key 'arn:aws:kms:{region}:012345678912:key/"
+                                    "{key_id}' does not exist".format(region=self.region, key_id=key_id))
         return json.dumps({'KeyRotationEnabled': rotation_enabled})
 
     def put_key_policy(self):
@@ -210,9 +194,8 @@ class KmsResponse(BaseResponse):
         try:
             self.kms_backend.put_key_policy(key_id, policy)
         except KeyError:
-            raise JSONResponseError(404, 'Not Found', body={
-                'message': "Key 'arn:aws:kms:{region}:012345678912:key/{key_id}' does not exist".format(region=self.region, key_id=key_id),
-                '__type': 'NotFoundException'})
+            raise NotFoundException("Key 'arn:aws:kms:{region}:012345678912:key/"
+                                    "{key_id}' does not exist".format(region=self.region, key_id=key_id))
 
         return json.dumps(None)
 
@@ -225,9 +208,8 @@ class KmsResponse(BaseResponse):
         try:
             return json.dumps({'Policy': self.kms_backend.get_key_policy(key_id)})
         except KeyError:
-            raise JSONResponseError(404, 'Not Found', body={
-                'message': "Key 'arn:aws:kms:{region}:012345678912:key/{key_id}' does not exist".format(region=self.region, key_id=key_id),
-                '__type': 'NotFoundException'})
+            raise NotFoundException("Key 'arn:aws:kms:{region}:012345678912:key/"
+                                    "{key_id}' does not exist".format(region=self.region, key_id=key_id))
 
     def list_key_policies(self):
         key_id = self.parameters.get('KeyId')
@@ -235,9 +217,8 @@ class KmsResponse(BaseResponse):
         try:
             self.kms_backend.describe_key(key_id)
         except KeyError:
-            raise JSONResponseError(404, 'Not Found', body={
-                'message': "Key 'arn:aws:kms:{region}:012345678912:key/{key_id}' does not exist".format(region=self.region, key_id=key_id),
-                '__type': 'NotFoundException'})
+            raise NotFoundException("Key 'arn:aws:kms:{region}:012345678912:key/"
+                                    "{key_id}' does not exist".format(region=self.region, key_id=key_id))
 
         return json.dumps({'Truncated': False, 'PolicyNames': ['default']})
 
@@ -252,8 +233,14 @@ class KmsResponse(BaseResponse):
         return json.dumps({"CiphertextBlob": base64.b64encode(value).decode("utf-8"), 'KeyId': 'key_id'})
 
     def decrypt(self):
+        # TODO refuse decode if EncryptionContext is not the same as when it was encrypted / generated
+
         value = self.parameters.get("CiphertextBlob")
-        return json.dumps({"Plaintext": base64.b64decode(value).decode("utf-8"), 'KeyId': 'key_id'})
+        try:
+            return json.dumps({"Plaintext": base64.b64decode(value).decode("utf-8")})
+        except UnicodeDecodeError:
+            # Generate data key will produce random bytes which when decrypted is still returned as base64
+            return json.dumps({"Plaintext": value})
 
     def disable_key(self):
         key_id = self.parameters.get('KeyId')
@@ -261,9 +248,8 @@ class KmsResponse(BaseResponse):
         try:
             self.kms_backend.disable_key(key_id)
         except KeyError:
-            raise JSONResponseError(404, 'Not Found', body={
-                'message': "Key 'arn:aws:kms:{region}:012345678912:key/{key_id}' does not exist".format(region=self.region, key_id=key_id),
-                '__type': 'NotFoundException'})
+            raise NotFoundException("Key 'arn:aws:kms:{region}:012345678912:key/"
+                                    "{key_id}' does not exist".format(region=self.region, key_id=key_id))
         return json.dumps(None)
 
     def enable_key(self):
@@ -272,9 +258,8 @@ class KmsResponse(BaseResponse):
         try:
             self.kms_backend.enable_key(key_id)
         except KeyError:
-            raise JSONResponseError(404, 'Not Found', body={
-                'message': "Key 'arn:aws:kms:{region}:012345678912:key/{key_id}' does not exist".format(region=self.region, key_id=key_id),
-                '__type': 'NotFoundException'})
+            raise NotFoundException("Key 'arn:aws:kms:{region}:012345678912:key/"
+                                    "{key_id}' does not exist".format(region=self.region, key_id=key_id))
         return json.dumps(None)
 
     def cancel_key_deletion(self):
@@ -283,9 +268,8 @@ class KmsResponse(BaseResponse):
         try:
             self.kms_backend.cancel_key_deletion(key_id)
         except KeyError:
-            raise JSONResponseError(404, 'Not Found', body={
-                'message': "Key 'arn:aws:kms:{region}:012345678912:key/{key_id}' does not exist".format(region=self.region, key_id=key_id),
-                '__type': 'NotFoundException'})
+            raise NotFoundException("Key 'arn:aws:kms:{region}:012345678912:key/"
+                                    "{key_id}' does not exist".format(region=self.region, key_id=key_id))
         return json.dumps({'KeyId': key_id})
 
     def schedule_key_deletion(self):
@@ -301,19 +285,62 @@ class KmsResponse(BaseResponse):
                 'DeletionDate': self.kms_backend.schedule_key_deletion(key_id, pending_window_in_days)
             })
         except KeyError:
-            raise JSONResponseError(404, 'Not Found', body={
-                'message': "Key 'arn:aws:kms:{region}:012345678912:key/{key_id}' does not exist".format(region=self.region, key_id=key_id),
-                '__type': 'NotFoundException'})
+            raise NotFoundException("Key 'arn:aws:kms:{region}:012345678912:key/"
+                                    "{key_id}' does not exist".format(region=self.region, key_id=key_id))
+
+    def generate_data_key(self):
+        key_id = self.parameters.get('KeyId')
+        encryption_context = self.parameters.get('EncryptionContext')
+        number_of_bytes = self.parameters.get('NumberOfBytes')
+        key_spec = self.parameters.get('KeySpec')
+        grant_tokens = self.parameters.get('GrantTokens')
+
+        # Param validation
+        if key_id.startswith('alias'):
+            if self.kms_backend.get_key_id_from_alias(key_id) is None:
+                raise NotFoundException('Alias arn:aws:kms:{region}:012345678912:{alias_name} is not found.'.format(
+                                        region=self.region, alias_name=key_id))
+        else:
+            if self.kms_backend.get_key_id(key_id) not in self.kms_backend.keys:
+                raise NotFoundException('Invalid keyId')
+
+        if number_of_bytes and (number_of_bytes > 1024 or number_of_bytes < 0):
+            raise ValidationException("1 validation error detected: Value '2048' at 'numberOfBytes' failed "
+                                  "to satisfy constraint: Member must have value less than or "
+                                  "equal to 1024")
+
+        if key_spec and key_spec not in ('AES_256', 'AES_128'):
+            raise ValidationException("1 validation error detected: Value 'AES_257' at 'keySpec' failed "
+                                  "to satisfy constraint: Member must satisfy enum value set: "
+                                  "[AES_256, AES_128]")
+        if not key_spec and not number_of_bytes:
+            raise ValidationException("Please specify either number of bytes or key spec.")
+        if key_spec and number_of_bytes:
+            raise ValidationException("Please specify either number of bytes or key spec.")
+
+        plaintext, key_arn = self.kms_backend.generate_data_key(key_id, encryption_context,
+                                                                number_of_bytes, key_spec, grant_tokens)
+
+        plaintext = base64.b64encode(plaintext).decode()
+
+        return json.dumps({
+            'CiphertextBlob': plaintext,
+            'Plaintext': plaintext,
+            'KeyId': key_arn  # not alias
+        })
+
+    def generate_data_key_without_plaintext(self):
+        result = json.loads(self.generate_data_key())
+        del result['Plaintext']
+
+        return json.dumps(result)
 
 
 def _assert_valid_key_id(key_id):
     if not re.match(r'^[A-F0-9]{8}-[A-F0-9]{4}-[A-F0-9]{4}-[A-F0-9]{4}-[A-F0-9]{12}$', key_id, re.IGNORECASE):
-        raise JSONResponseError(404, 'Not Found', body={
-                                'message': ' Invalid keyId', '__type': 'NotFoundException'})
+        raise NotFoundException('Invalid keyId')
 
 
 def _assert_default_policy(policy_name):
     if policy_name != 'default':
-        raise JSONResponseError(404, 'Not Found', body={
-            'message': "No such policy exists",
-            '__type': 'NotFoundException'})
+        raise NotFoundException("No such policy exists")
